initialValue property
dynamic
initialValue
final
The initial value to be shown in the generated field
Implementation
final dynamic? initialValue;
The initial value to be shown in the generated field
final dynamic? initialValue;