InputField class
The model from which the FormField is generated, in relation to the fields received.
- Annotations
Constructors
-
InputField({required String id, required FieldType fieldType, String? hintText, Widget? prefixIcon, dynamic initialValue, List<
DropdownMenuItem< ? items, TextEditingController? controller, String? validator(String?)?, FocusNode? focusNode})String> > - The model from which the FormField is generated, in relation to the fields received.
Properties
- controller → TextEditingController?
-
Controls the text being edited.
final
- fieldType → FieldType
-
The type of the field you're trying to show
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- id → String
-
The key of the input for the result map, after validation
final
- initialValue → dynamic
-
The initial value to be shown in the generated field
final
-
items
→ List<
DropdownMenuItem< ?String> > -
final
- prefixIcon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validator → String? Function(String?)?
-
The validation required f
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited